@@ -17,18 +17,14 @@ from poorwsgi.state import OK, DONE, DECLINED, HTTP_ERROR, HTTP_OK, \
             METHOD_GET, METHOD_POST, METHOD_HEAD, methods, LOG_INFO, LOG_ERR, \
             HTTP_METHOD_NOT_ALLOWED, HTTP_NOT_FOUND, \
             __author__, __date__, __version__
-from poorwsgi.request import Request, uni
+from poorwsgi.request import Request
 from poorwsgi.results import default_shandlers, not_implemented, internal_server_error, \
-            SERVER_RETURN, send_file, directory_index, debug_info
+            SERVER_RETURN, send_file, directory_index, debug_info, \
+            _unicode_exist, uni
 
 # check, if there is define filter in uri
 re_filter = re.compile(r'<(\w+)(:[^>]+)?>')
 
-if version_info[0] < 3:         # python 2.x
-    _unicode_exist = True
-else:                           # python 3.x
-    _unicode_exist = False
-
 class Application(object):
     """ Poor WSGI application which is called by WSGI server, how, is describe
         in PEP 0333. This object store route dispatch table, and have methods
@@ -476,7 +472,7 @@ class Application(object):
 
         # try file or index
         if req.document_root():
-            rfile = "%s%s" % (req.document_root(), path.normpath("%s" % req.uri))
+            rfile = "%s%s" % (uni(req.document_root()), path.normpath("%s" % uni(req.uri)))
 
             if not path.exists(rfile):
                 if req.debug and req.uri == '/debug-info':      # work if debug
